# ADRIA.jl Documentation

ADRIA is a multi-criteria decision support platform for informing reef restoration and adaptation interventions.


## Quick start

### Setup

To specify user-specific options, a `config.toml` file should be created with the following options (adjusted to suit your needs):

```toml
[operation]
num_cores = 2     # No. of cores to use. Values <= 0 will use all available cores.
threshold = 1e-6  # Result values below this will be set to 0.0
debug = false     # Disable multi-processing to allow error messages to be shown

[results]
output_dir = "./Outputs"  # Change this to point to where you want to store results
```

!!! tip "Performance"
    ADRIA uses an on-disk data store to hold results from model runs.
    Setting `output_dir` to a directory on an SSD (Solid State Drive)
    will maximize performance.


### Usage

```julia
# Import ADRIA package
using ADRIA


# Load input dataset ("Input Set") for a spatial domain
dom = ADRIA.load_domain("path to Input Set")

# Generate 100 scenarios based on available environmental data layers and model parameters
scens = ADRIA.sample(dom, 100)

# Run sampled scenarios for a given RCP
rs = ADRIA.run_scenarios(scens, dom, "45")

# ... or repeatedly run scenarios across several RCPs
rs = ADRIA.run_scenarios(scens, dom, ["45", "60", "85"])

# then extract metrics for analysis
tac = ADRIA.metrics.total_absolute_cover(rs)
```


## Troubleshooting F.A.Q

ADRIA.jl is under active development and from time to time issues may arise.
Here are some answers to some issues encountered.

**Q. I get this warning when trying to load pre-existing results:**
  `Results were produced with a different version of ADRIA (v0.x.x). The installed version of ADRIA is: v0.y.y. Errors may occur when analyzing data.` 
  (where `x` and `y` are different numbers).

**A.** The result set being loaded were generated by a different version of ADRIA, and in a possibly incompatible format.
  Sometimes, results may still be produced/analyzed as normal. In other times, ADRIA.jl or the expected metadata in the result set may have changed
  leading to errors when conducting analyses.

  Either go back to the version indicated, or re-run the scenarios to obtain results in the updated format.

**Q. I get an error or warning about an `ENV` variable not being found or set.**

**A.** Double check the configuration settings in `config.toml` (see above).

**Q. How do I run my own scenarios?**

**A.** Scenarios are defined in a CSV file (with parameter values in columns, so that each row defines a scenario).

  - See the `example_scenarios.csv` file in the `examples` directory for an idea of what this looks like.
  - See `parameters.jl` file in the `examples` directory on how to extract the model specification and parameter table for a given domain.
  - See also the `running_scenarios.jl` example script which showcases how to run such a file for a given study area.